কম্পিউটার টিউটোরিয়াল

Windows 10-এ WSL কীভাবে ইনস্টল করবেন?

Microsoft ২০১৭ সালে WSL (Windows Subsystem for Linux) চালু করে, যা ব্যবহারকারীদের Windows PC-এ (Hyper-V বা ডুয়াল বুট ছাড়া) কমান্ড-লাইন ইন্টারফেসে বিভিন্ন Linux কমান্ড এবং টুল চালানোর সুযোগ দিয়েছিল।

২০১৯ সালে, Microsoft WSL-এর একটি নতুন ভার্সন রিলিজ করার ঘোষণা দিয়েছে, এবং সেটিকে WSL 2 নামে নামকরণ করা হয়েছে। WSL-এর এই নতুন ভার্সন Windows PC-এ গ্রাফিক্যাল Linux অ্যাপ চালানোর সমর্থন করে এবং একটি পুরোপুরি কার্যকর Linux 커널 ব্যবহার করে যেটির ফাইল I/O পারফরম্যান্স ভালো এবং সিস্টেম কল দ্রুত। WSL 2-র আরেকটি অনন্য উপলব্ধি হল এটি Windows 10 Home ভার্সনেও সমর্থিত, যায় WSL শুধু Windows 10 Pro-তে সমর্থিত ছিল।

Windows 10-এ WSL কীভাবে ইনস্টল করবেন?

WSL ফিচার সক্রিয় করার জন্য প্রয়োজনীয় শর্তাবলী

একজন ব্যবহারকারীর PC নিচের শর্তাবলী পূরণ করতে হবে WSL ফিচার সক্রিয় করার জন্য:

  • Hyper-V সমর্থন করা উচিত
  • Windows-এর 64-বিট ভার্সন
  • Windows 10 ভার্সন 1903 বা উচ্চতর। ARM মেশিনের ক্ষেত্রে, Windows 10 ভার্সন 2004 বা উচ্চতর। Windows 11 স্বাভাবিকভাবে WSL 2 সমর্থন করে।

আপনার PC যদি এই শর্তাবলী পূরণ না করে, তবে আপনাকে শুধু WSL 1 ভার্সন ব্যবহার করতে হতে পারে এবং নিচের গাইডলাইন ফলো করতে পারেন কিন্তু WSL 2-র সাথে সম্পর্কিত অংশগুলো (যেমন ডিফল্ট ভার্সন WSL 2 সেট করা) বাদ দিয়ে।

যদি আপনার PC WSL 2-এর সিস্টেম রিকোয়ারমেন্ট পূরণ করে, তবে নিচের গাইডলাইনগুলো ফলো করতে পারেন:

PowerShell-এর মাধ্যমে WSL ইনস্টল করুন

Microsoft ব্যবহারকারীদের জন্য একটি একক PowerShell কমান্ড দিয়ে WSL ফিচার সহ ডিফল্ট Ubuntu ইনস্টলেশন ইনস্টল করা সহজ করে দিয়েছে (যেটি পরিবর্তন করা যায়)। এই PowerShell কমান্ডটি প্রয়োজনীয় WSL কম্পোনেন্ট সক্রিয় করবে, লেটেস্ট Linux কার্নেল ডাউনলোড ও ইনস্টল করবে, WSL 2-কে ডিফল্ট হিসেবে সেট করবে, এবং Ubuntu ইনস্টল করবে। তাই, নিচের ধাপগুলো ফলো করুন WSL একটি কমান্ড দিয়ে সেট আপ করতে (এই কমান্ডটি শুধু Windows 10 2004 বা উচ্চতরে সমর্থিত):

  1. Windows-এ ডান ক্লিক করুন এবং PowerShell (Admin) নির্বাচন করুন।
  2. এখন নিচের কমান্ড এক্সিকিউট করুন:
    wsl --install
    Windows 10-এ WSL কীভাবে ইনস্টল করবেন?
  3. সব কম্পোনেন্টের ইনস্টলেশন প্রসেস সম্পন্ন হওয়ার পর্যন্ত অপেক্ষা করুন এবং তারপর আপনার PC রিবুট করুন।
  4. রিবুট হলে, আপনি Ubuntu ডিস্ট্রিবিউশন সেট আপ করতে পারেন আপনার প্রয়োজন অনুযায়ী (পরে আলোচনা করা হয়েছে) এবং আপনি Linux-এর অদ্ভুত বিশ্বে ভ্রমণের জন্য প্রস্তুত।

আপনি Windows Start মেনুর Ubuntu অ্যাপ বা Windows Terminal অ্যাপ ব্যবহার করে Ubuntu-এর বিভিন্ন ফিচার এক্সপ্লোর করতে পারেন।

PowerShell কমান্ড দিয়ে নন-ডিফল্ট Linux ডিস্ট্রো ইনস্টল করুন

যদি কোনো ব্যবহারকারী ডিফল্ট Ubuntu ছাড়া অন্য ডিস্ট্রিবিউশন ইনস্টল করতে চান? চিন্তা করবেন না, এখানে একটি সহজ প্রসেস আছে:

  1. Windows PowerShell (Admin) খুলুন এবং WSL-এর জন্য উপলব্ধ Linux ডিস্ট্রোর তালিকা চেক করতে নিচের কমান্ড এক্সিকিউট করুন:
    wsl --list --online

    অথবা

    wsl -l -o
    Windows 10-এ WSL কীভাবে ইনস্টল করবেন?
  2. এখন, উপলব্ধ Linux ডিস্ট্রোর তালিকা চেক করুন এবং খুঁজে বের করুন কোনটি আপনার প্রয়োজন পূরণ করে। সাধারণত নিচেরগুলো উপলব্ধ হিসেবে দেখানো হতে পারে:
    Ubuntu Debian kali-linux opensuse-42 SLES-12
  3. তারপর, প্রয়োজনীয় Linux ডিস্ট্রো ইনস্টল করার জন্য নিচের কমান্ড এক্সিকিউট করুন (নিশ্চিত করুন -কে ডিস্ট্রো নাম দিয়ে রিপ্লেস করেছেন):
    wsl --install -d <Distribution Name>

    উদাহরণস্বরূপ, Debian ইনস্টল করতে, আপনি এই কমান্ডটি ব্যবহার করতে পারেন:

    wsl --install -d Debian
    Windows 10-এ WSL কীভাবে ইনস্টল করবেন?
  4. এখন, ইনস্টলেশন সম্পন্ন হওয়ার পর্যন্ত অপেক্ষা করুন এবং আপনার সিস্টেম রিস্টার্ট করুন।

রিস্টার্ট হলে, Linux ডিস্ট্রো সেট আপ করুন আপনার প্রয়োজন অনুযায়ী (যেমন আগে আলোচনা করা হয়েছে)।

কাস্টম Linux ডিস্ট্রো ইনস্টল করুন

কিছু ব্যবহারকারী থাকতে পারে যাদের Microsoft Store-এ উপলব্ধ নয় এমন একটি Linux ডিস্ট্রো ব্যবহার করতে হয়। সেই ব্যবহারকারীরা অফিসিয়াল Microsoft রেফারেন্স পেজ ব্যবহার করে যেকোনো Linux ডিস্ট্রিবিউশন ইম্পোর্ট করতে পারেন WSL-এর সাথে ব্যবহার করার জন্য, এটিকে এখানে আলোচনা করা এই আর্টিকেলের স্কোপের বাইরে।

WSL-এ একাধিক Linux ডিস্ট্রো ইনস্টল করুন

যদি কোনো ব্যবহারকারী একাধিক Linux ডিস্ট্রো ব্যবহার করতে চান, তবে সে (ইতিমধ্যে আলোচনা করা) নিচের কমান্ডটি PowerShell-এ ব্যবহার করে এটি করতে পারেন (ভুলবেন না -কে ডিস্ট্রো নাম দিয়ে রিপ্লেস করতে, যেমন Debian)

wsl --install -d <Distribution Name>

যদি একাধিক ডিস্ট্রো ইনস্টল থাকে, তবে একজন ব্যবহারকারী WSL-এ ইনস্টল করা WSL ডিস্ট্রোগুলো চেক করতে পারেন PowerShell (Admin)-এ নিচের যেকোনো একটি এক্সিকিউট করে:

wsl -l -v

অথবা

wsl --list --all
Windows 10-এ WSL কীভাবে ইনস্টল করবেন?

মনে রাখবেন যদি আপনি bash-এ WSL কমান্ড এক্সিকিউট করার চেষ্টা করেন, তবে নিশ্চিত করুন WSL-এর শেষে .exe লিখেছেন, উদাহরণস্বরূপ, bash-এর ভিতর থেকে Linux ডিস্ট্রিবিউশন ইনস্টল করতে, নিচের কমান্ডটি এক্সিকিউট করুন:

wsl.exe --install -d <Distribution Name>

সার্ভারে WSL ইনস্টল করুন

যদি আপনি সার্ভার মেশিনে WSL ইনস্টল করেন, তবে আপনি অফিসিয়াল Microsoft Windows Server Installation Guide of WSL রেফারেন্স করতে পারেন।

VM-ভিত্তিক Windows-এ WSL ইনস্টল করুন

যদি কোনো ব্যবহারকারী VM-ভিত্তিক Windows-এ WSL ফিচার ইনস্টল করেন, তবে সে হোস্টের PowerShell (Admin)-এ নিচের কমান্ড এক্সিকিউট করতে পারেন হোস্টের ভার্চুয়ালাইজেশন ফ্ল্যাগগুলো VM-এ এক্সপোজ করার জন্য:

Set-VMProcessor -VMName MyWSL -ExposeVirtualizationExtensions $true

Linux ডিস্ট্রিবিউশন এবং WSL ভার্সন ইনস্টলেশন কনফার্ম করুন

এখন, Linux ডিস্ট্রিবিউশনগুলো সফলভাবে ইনস্টল হয়েছে কিনা এবং WSL ভার্সন WSL 2-তে সেট হয়েছে কিনা তা কনফার্ম করতে, একজন ব্যবহারকারী নিচের কমান্ডগুলো (একে একে) PowerShell (Admin)-এ এক্সিকিউট করতে পারেন:

wsl.exe --list --all wsl --list --verbose
Windows 10-এ WSL কীভাবে ইনস্টল করবেন?

GUI মেথড ব্যবহার করে WSL ইনস্টল করুন

অনেক Windows ব্যবহারকারী অ্যাপ্লিকেশন/ইউটিলিটি ইনস্টল করার জন্য কমান্ড-লাইন মেথড পছন্দ করেন না। এছাড়া, WSL ভার্সন 1 আগে আলোচনা করা একক PowerShell কমান্ড দিয়ে ইনস্টল করা যায় না। বরং, Windows 10 ভার্সন 1903 এবং 1909-এর ব্যবহারকারীরা WSL ইনস্টল মেথড ব্যবহার করতে পারেন না। তাই, এখানে একটি আরও GUI-ভিত্তিক মেথড দেওয়া হলো Windows PC-এ WSL ব্যবহার করার জন্য।

Windows 10-এ WSL ফিচার সক্রিয় করুন

  1. Windows-এ ক্লিক করুন, সার্চ করে Turn Windows Features on or off খুলুন।Windows 10-এ WSL কীভাবে ইনস্টল করবেন?
  2. এখন নিচের দুটো সক্রিয় করুন সংশ্লিষ্ট চেকবক্সে চেকмар্ক দিয়ে:
    Virtual Machine Platform Windows Subsystem for Linux
    Windows 10-এ WSL কীভাবে ইনস্টল করবেন?
  3. তারপর OK বাটনে ক্লিক করুন এবং সিস্টেমকে সংশ্লিষ্ট ফাইলগুলো ডাউনলোড/ইনস্টল করার দিন (নিশ্চিত করুন ইন্টারনেট কানেকশন আছে)।
  4. হওয়ায়, আপনার সিস্টেম রিস্টার্ট করুন।

Windows Subsystem for Linux (WSL) এছাড়া এক্সিকিউট করে সক্রিয় করা যায় PowerShell (Admin)-এ নিচের কমান্ড দিয়ে:

dism.exe /online /enable-feature /featurename:Microsoft-Windows-Subsystem-Linux /all /norestart
Windows 10-এ WSL কীভাবে ইনস্টল করবেন?

Virtual Machine Platform সক্রিয় করা যায় PowerShell (Admin)-এ নিচের কমান্ড এক্সিকিউট করে:

Windows Version 2004 বা উচ্চতর জন্য:

dism.exe /online /enable-feature /featurename:VirtualMachinePlatform /all /norestart
Windows 10-এ WSL কীভাবে ইনস্টল করবেন?

Windows Version 1903 এবং 1909-এর জন্য:

Enable-WindowsOptionalFeature -Online -FeatureName VirtualMachinePlatform -NoRestart

WSL-এর লেটেস্ট কার্নেল আপডেট ডাউনলোড এবং ইনস্টল করুন

প্রয়োজনীয় ফিচারগুলো সক্রিয় করার পর, একজন ব্যবহারকারীর WSL কার্নেল আপডেট করতে হবে।

  1. Microsoft থেকে লেটেস্ট WSL কার্নেল আপডেট ডাউনলোড করুন। ARM64 মেশিনের ব্যবহারকারীরা ARM64 WSL Package ডাউনলোড করতে পারেন।
  2. ডাউনলোড হলে, ডাউনলোড করা ফাইলটির ওপর রাইট-ক্লিক করুন, Run as Administrator নির্বাচন করুন, এবং প্রম্পটগুলো ফলো করুন WSL কার্নেল আপডেট করার জন্য।Windows 10-এ WSL কীভাবে ইনস্টল করবেন?

WSL-এর ডিফল্ট ভার্সন WSL 2-তে সেট করুন

WSL কার্নেল আপডেট করার পর, একজন ব্যবহারকারীর ডিফল্ট WSL ভার্সন 2-তে সেট করতে হবে। কিন্তু তার আগে, চেক করুন কোন WSL ভার্সন ডিফল্ট হিসেবে সেট আছে PowerShell (Admin)-এ নিচের কমান্ড এক্সিকিউট করে:

wsl -l -v

যদি WSL 2 ডিফল্ট না হয়, তবে PowerShell (Admin) খুলুন এবং নিচের কমান্ড এক্সিকিউট করুন:

wsl --set-default-version 2
Windows 10-এ WSL কীভাবে ইনস্টল করবেন?

এটি Linux ডিস্ট্রোর সব নতুন ইনস্টলেশনের জন্য WSL-tকে WSL 2-এ পরিবর্তন করবে। যদি কোনো ব্যবহারকারী ইতিমধ্যে WSL-এ একটি ডিস্ট্রো ইনস্টল করে থাকেন, তবে সে নিচের কমান্ড এক্সিকিউট করতে পারেন (নিশ্চিত করুন -কে ডিস্ট্রো নাম দিয়ে রিপ্লেস করেছেন) তার WSL ভার্সন 2-তে পরিবর্তন করতে:

wsl --set-version <DistributionName> 2

উদাহরণস্বরূপ:

wsl --set-version Ubuntu 2
Windows 10-এ WSL কীভাবে ইনস্টল করবেন?

Microsoft Store থেকে Linux ডিস্ট্রো ইনস্টল করুন

ডিফল্ট WSL ভার্সন 2-তে সেট আপ করার পর, একজন ব্যবহারকারীর একটি Linux ডিস্ট্রো ইনস্টল করতে হবে।

  1. Windows-এ ক্লিক করুন, সার্চ করুন, এবং Microsoft Store খুলুন।
  2. এখন পছন্দের Linux ডিস্ট্রিবিউশন সার্চ করুন। নিচে উপলব্ধ Linux ডিস্ট্রোর তালিকা দেওয়া হলো:
    Ubuntu openSUSE Leap 15.1 SUSE Linux Enterprise Server 12 SP5 Kali Linux Debian GNU/Linux Fedora Remix for WSL Pengwin Pengwin Enterprise Alpine WSL Raft (Free Trial)
  3. একবার নির্বাচন হলে, পছন্দের Linux ডিস্ট্রো খুলুন এবং Get-এ ক্লিক করুন।
  4. তারপর Install-এ ক্লিক করুন এবং ডিস্ট্রো ইনস্টল হওয়ার জন্য অপেক্ষা করুন (যেমন, Ubuntu)।
  5. তারপর, আপনার সিস্টেম রিস্টার্ট করুন এবং পরবর্তী ধাপে আলোচনা করা ভাবে ডিস্ট্রো কনফিগার করুন।Windows 10-এ WSL কীভাবে ইনস্টল করবেন?

ইনস্টলের পর Linux ডিস্ট্রো কনফিগার করুন

  1. Linux ডিস্ট্রিবিউশন ইনস্টল হলে, এটিকে লঞ্চ করুন (Start মেনু থেকে বা কমান্ড-লাইন টুল থেকে) এবং একটি Command Prompt উইন্ডো দেখাবে।
  2. এখন, Ubuntu-এর জন্য একটি ইউজার নাম লিখুন (lowercase-এ) (এটি Windows क्रেডেনশিয়াল থেকে আলাদা হতে পারে)।
  3. তারপর Ubuntu অ্যাকাউন্টের জন্য একটি পাসওয়ার্ড লিখুন এবং পরে, পাসওয়ার্ড কনফার্ম করুন।Windows 10-এ WSL কীভাবে ইনস্টল করবেন?
  4. এখন আপনার প্রয়োজন অনুযায়ী বিভিন্ন Linux কমান্ড ব্যবহার করুন।
  5. Ubuntu bash থেকে বের হতে bash-এ Exit এক্সিকিউট করুন।

WSL-এ Linux ডিস্ট্রো খোলার পদ্ধতিগুলো

Windows-এ ইনস্টল করা একটি Linux ডিস্ট্রো খোলার একাধিক পদ্ধতি আছে:

  1. আপনি Windows Start মেনু-এ Linux ডিস্ট্রোর নাম টাইপ করে সেটা সেখান থেকে লঞ্চ করতে পারেন।Windows 10-এ WSL কীভাবে ইনস্টল করবেন?
  2. Windows Command Prompt বা PowerShell থেকে ডিস্ট্রোর নাম (যেমন Ubuntu) টাইপ করে Enter চাপায়।
  3. Command Prompt বা PowerShell-এ WSL.exe এক্সিকিউট করুন বর্তমান শেলে Linux টার্মিনাল খোলার জন্য বা wsl [command] ব্যবহার করুন WSL কমান্ড এক্সিকিউট করার জন্য। একাধিক ডিস্ট্রোর ক্ষেত্রে, একজন ব্যবহারকারী ডিফল্ট ডিস্ট্রো কনফিগার করতে পারেন নিচের কমান্ড এক্সিকিউট করে:
    wsl -s <DistributionName>

    উদাহরণস্বরূপ

    wsl -s Debian
  4. একটি নির্দিষ্ট WSL ডিস্ট্রো খোলার জন্য, একজন ব্যবহারকারী PowerShell (Admin)-এ নিচের কমান্ড এক্সিকিউট করতে পারেন:
    wsl -d <DistributionName>
  5. শেষে কিন্তু সবচেয়ে ভালো এবং আমার প্রিয়: Windows Terminal।

Windows Terminal ইনস্টল করুন

Windows Terminal একটি Microsoft টার্মিনাল এমুলেটর যা একাধিক ট্যাব সমর্থন করে এবং Windows কনসোলের প্রতিস্থাপন। Windows Terminal দিয়ে WSL ব্যবহার করা খুব সহজ। Windows Terminal ইনস্টল করতে:

  1. Microsoft Store খুলুন এবং Windows Terminal সার্চ করুন।
  2. এখন Get-এ ক্লিক করুন এবং তারপর Install-এ ক্লিক করুন।
  3. ইনস্টল হলে, এটিকে লঞ্চ করুন এবং WSL কমান্ড এক্সিকিউট করতে এটি ব্যবহার করুন।Windows 10-এ WSL কীভাবে ইনস্টল করবেন?

Linux ডিস্ট্রো এবং কার্নেলকে লেটেস্ট বিল্ডে আপডেট করুন

Linux ডিস্ট্রিবিউশন কনফিগার করার পর, প্রথম ধাপ হওয়া উচিত এটি আপডেট করা কারণ Microsoft এই ডিস্ট্রোগুলো অটো-আপডেট করে না। এটি করতে, Linux bash-এ নিচের কমান্ড এক্সিকিউট করুন:

sudo apt update && sudo apt upgrade
Windows 10-এ WSL কীভাবে ইনস্টল করবেন?

WSL কার্নেল আপডেট করতে, PowerShell (Admin)-এ নিচের কমান্ড এক্সিকিউট করুন:

wsl –update
Windows 10-এ WSL কীভাবে ইনস্টল করবেন?

WSL-এর সাধারণ স্ট্যাটাস চেক করতে, PowerShell (Admin)-এ নিচের কমান্ড এক্সিকিউট করুন:

wsl --status

সাধারণ Linux প্যাকেজ ইনস্টল করুন

ডিস্ট্রো আপডেট হলে, একজন ব্যবহারকারী WSL-এ বিভিন্ন Linux প্যাকেজ ইনস্টল করতে চাইতে পারে। একজন ব্যবহারকারী APT প্যাকেজ রিপোজিটরি ব্যবহার করে bash-এ নিচের কমান্ড এক্সিকিউট করতে পারেন (যেমন, htop ইনস্টল করতে):

$ sudo apt install htop
Windows 10-এ WSL কীভাবে ইনস্টল করবেন?

এবং htop লঞ্চ করা যায় bash-এ নিচের কমান্ড এক্সিকিউট করে:

$ htop

Kali-Linux-এর জন্য GUI Win-Kex ইনস্টল করতে, একজন ব্যবহারকারী bash-এ নিচের কমান্ডগুলো (একে একে) এক্সিকিউট করতে পারেন:

sudo apt update sudo apt install -y kali-win-kex

ইনস্টল হলে, আপনি Win-Kex বিভিন্ন অপশনে চালাতে পারেন। বিস্তারিত Official Kali ডকুমেন্টেশনে পাওয়া যাবে।

WSL এবং Windows ফাইল সিস্টেম

Linux ফাইলগুলো Windows-এ কোথায় অবস্থিত? একটি স্বাভাবিক প্রশ্ন ব্যবহারকারীর মনে আসে। WSL-এর ফাইল সিস্টেম ইনস্টল থাকে নিচের লোকেশনে (এই ডিরেক্টরিতে ফাইল পরিবর্তন বা ডিলিট করবেন না):

%LOCALAPPDATA%\Lxss\

ব্যবহারের সময়, একজন ব্যবহারকারীর হোস্টের ফাইল সিস্টেম WSL-এ অ্যাক্সেস করতে হতে পারে। এটি করতে, bash-এ নিচের কমান্ড এক্সিকিউট করুন:

/mnt/c/
Windows 10-এ WSL কীভাবে ইনস্টল করবেন?

WSL 1 ফিচার সক্রিয় করুন

কখনো কখনো একজন ব্যবহারকারী WSL 1 ইনস্টল করতে চায় (WSL 2 না) এবং সেক্ষেত্রে, উপরের ধাপগুলো ফলো করুন, শুধু WSL 2-র অংশগুলো বাদ দিয়ে। ডিফল্ট WSL পরিবর্তন করতে, একজন ব্যবহারকারী PowerShell (Admin)-এ নিচের কমান্ড এক্সিকিউট করতে পারেন:

wsl --set-default-version 1

তারপর, ব্যবহারকারী তার প্রয়োজন পূরণ করার জন্য একটি নতুন Linux ডিস্ট্রো ইনস্টল করতে পারেন (যেমন আগে আলোচনা করা হয়েছে)।

যদি WSL ভার্সন 1-এ পরিবর্তন করা না যায়, এক্সিকিউট করুন PowerShell (Admin)-এ:

New-ItemProperty HKCU:\SOFTWARE\Microsoft\Windows\CurrentVersion\Lxss DefaultVersion -Value 1 -Force

তারপর, আপনার সিস্টেম রিবুট করুন এবং রিবুট হলে, Virtual Machine Platform ডিজেবল করুন। তারপর, আপনার সিস্টেম WSL 1 ব্যবহার করার জন্য কনফিগার হয়ে যাবে।

সিস্টেম থেকে WSL এবং Linux ডিস্ট্রো সরিয়ে ফেলুন

আপনি যদি WSL-এ কাজ শেষ করে ফেলেন এবং সিস্টেম থেকে এটি সরাতে চান, তবে এটি করার একটি সহজ প্রসেস:

  1. Windows-এ ডান ক্লিক করুন এবং Apps & Features খুলুন।
  2. এখন Linux ডিস্ট্রো (যেমন, Ubuntu) এক্সপ্যান্ড করুন এবং Uninstall-এ ক্লিক করুন।Windows 10-এ WSL কীভাবে ইনস্টল করবেন?
  3. তারপর, ডিস্ট্রো আনইনস্টল করার জন্য কনফার্ম করুন এবং আপনার PC রিবুট করুন।
  4. রিবুট হলে, Virtual Machine Platform এবং Windows Subsystem for Linux ডিজেবল করুন (যেমন আগে আলোচনা করা হয়েছে) Turn Windows Features on or off-এ।Windows 10-এ WSL কীভাবে ইনস্টল করবেন?
  5. এখন আপনার PC রিবুট করুন এবং রিবুট হলে, WSL PC থেকে সরিয়ে ফেলা হয়েছে।

তো, এই ছিল সारा কিছু, আশা করি এই আর্টিকেলটি তার উদ্দেশ্য সফল করেছে এবং WSL-এর মৌলিক ধারণাগুলো স্পষ্ট করে দিয়েছে।

  1. Windows 10 ক্লিন ইনস্টল করার পূর্ণাঙ্গ গাইড

  2. উইন্ডোজ ১০-এ ব্লুটুথ ইনস্টল ও সমস্যা সমাধান: সম্পূর্ণ গাইড

  3. Chromebook-এ Windows ইনস্টল করার ধাপে ধাপে গাইড

  4. Windows 10-এ Windows 98 ক্লাসিক আইকন ইনস্টল করুন: ধাপে ধাপে গাইড